==> 1387912911_16_bit_adc_ads83_mikroc_avr.zip: maketka/maket.c <==
/*
Roman Yu. Toropov
*/

// LCD module connections
sbit LCD_RS at PORTA5_bit;
sbit LCD_EN at PORTA4_bit;
sbit LCD_D4 at PORTA3_bit;
sbit LCD_D5 at PORTA2_bit;
sbit LCD_D6 at PORTA1_bit;
sbit LCD_D7 at PORTA0_bit;

sbit LCD_RS_Direction at DDA5_bit;
sbit LCD_EN_Direction at DDA4_bit;
sbit LCD_D4_Direction at DDA3_bit;
sbit LCD_D5_Direction at DDA2_bit;
sbit LCD_D6_Direction at DDA1_bit;
sbit LCD_D7_Direction at DDA0_bit;
// End LCD module connections

// ADC module connections
sbit Chip_Select_Direction at DDA6_bit;
sbit Chip_Select at PORTA6_bit;
float measurement1, measurement2, measurement3, measurement4;
char measuremen1[15], measuremen2[15], measuremen3[15], measuremen4[15];
// end ADC module connections


void init_adc() {

  measurement1 = 0;
  measurement2 = 0;
  measurement3 = 0;
  measurement4 = 0;                               // Initialize the measurement variable

// Init SPI
  SPI1_Init_Advanced(_SPI_MASTER,                // Initialize AVR as master
                     _SPI_FCY_DIV16,             // Data sample at end
                     _SPI_CLK_LO_LEADING);

  Chip_Select_Direction = 1;                     // SetBit
  Chip_Select= 1;                                // SetBit
}//~

float getADC(unsigned short channel) {    // Returns 0..65535
  unsigned int tmp;
  Chip_Select= 0;                                // Select ADS8341
  if (channel == 0) { SPI1_Write(0x97); }        // SPI communication  0=97, 1=D7, 2=A7, 3=E7
  if (channel == 1) { SPI1_Write(0xD7); }
  if (channel == 2) { SPI1_Write(0xA7); }
  if (channel == 3) { SPI1_Write(0xE7); }
  Delay_us(100);

  tmp = SPI1_Read(0);
  tmp = tmp << 9;                                // Get ADC value
  tmp |= SPI1_Read(0);
  // tmp = tmp << 1;
  // tmp |= SPI1_Read(0);
  Chip_Select= 1;
  return tmp;
}

void adc_read() {
     measurement1 = (getADC(0)+0)/16000;
     sprintf(measuremen1,"%1.3f", measurement1);

     measurement2 = (getADC(1)+0)/16000;
     sprintf(measuremen2,"%1.3f", measurement2);

     measurement3 = (getADC(2)+0)/16000;
     sprintf(measuremen3,"%1.3f", measurement3);

     measurement4 = (getADC(3)+0)/16000;
     sprintf(measuremen4,"%1.3f", measurement4);


}

void print_adc() {
  Lcd_Out(1,1,measuremen1);
  Lcd_Out(2,1,measuremen2);
  Lcd_Out(1,12,measuremen3);
  Lcd_Out(2,12,measuremen4);
}


void system_init() {
  init_adc();
  Lcd_Init();                        // Initialize LCD
  Lcd_Cmd(_LCD_CLEAR);               // Clear display
  Lcd_Cmd(_LCD_CURSOR_OFF);          // Cursor off
  Lcd_Out(1,5,"ADC ADS8341");
  Lcd_Out(2,1,"ATmega128 16 MHz");

}


void main() {
  system_init();
  Lcd_Cmd(_LCD_CLEAR);

     while(1){
       // Lcd_Cmd(_LCD_CLEAR);               // Clear display
       adc_read();
       print_adc();
       // Delay_ms(90);
     }


}

==> 1388207230_16_bit_adc_ads83_mikroc_avr.zip: maketka/maket.c <==
/*
Roman Yu. Toropov
*/

// LCD module connections
sbit LCD_RS at PORTA5_bit;
sbit LCD_EN at PORTA4_bit;
sbit LCD_D4 at PORTA3_bit;
sbit LCD_D5 at PORTA2_bit;
sbit LCD_D6 at PORTA1_bit;
sbit LCD_D7 at PORTA0_bit;

sbit LCD_RS_Direction at DDA5_bit;
sbit LCD_EN_Direction at DDA4_bit;
sbit LCD_D4_Direction at DDA3_bit;
sbit LCD_D5_Direction at DDA2_bit;
sbit LCD_D6_Direction at DDA1_bit;
sbit LCD_D7_Direction at DDA0_bit;
// End LCD module connections

// ADC module connections
sbit Chip_Select_Direction at DDA6_bit;
sbit Chip_Select at PORTA6_bit;
float measurement1, measurement2, measurement3, measurement4;
char measuremen1[15], measuremen2[15], measuremen3[15], measuremen4[15];
// end ADC module connections


void init_adc() {

  measurement1 = 0;
  measurement2 = 0;
  measurement3 = 0;
  measurement4 = 0;                               // Initialize the measurement variable

// Init SPI
  SPI1_Init_Advanced(_SPI_MASTER,                // Initialize AVR as master
                     _SPI_FCY_DIV64,             // Data sample at end
                     _SPI_CLK_LO_LEADING);

  Chip_Select_Direction = 1;                     // SetBit
  Chip_Select= 1;                                // SetBit
}//~

float getADC(unsigned short channel) {    // Returns 0..32767, no the MSB, No most significant bit
  unsigned int tmp;
  Chip_Select= 0;                                // Select ADS8341
  if (channel == 0) { SPI1_Write(0x96); }        // SPI communication
  if (channel == 1) { SPI1_Write(0xD6); }
  if (channel == 2) { SPI1_Write(0xA6); }
  if (channel == 3) { SPI1_Write(0xE6); }
  Delay_us(10);                                 // Wait BUSY

  tmp = SPI1_Read(0);
  tmp = tmp << 8;                                // Get ADC value
  tmp |= SPI1_Read(0);
  Chip_Select= 1;
  // tmp = tmp + 50;
  return tmp;
}

void adc_read() {
     measurement1 = (getADC(0)+0)/8000;
     sprintf(measuremen1,"%1.3f", measurement1);

     measurement2 = (getADC(1)+0)/8000;
     sprintf(measuremen2,"%1.3f", measurement2);

     measurement3 = (getADC(2)+0)/8000;
     sprintf(measuremen3,"%1.3f", measurement3);

     measurement4 = (getADC(3)+0)/8000;
     sprintf(measuremen4,"%1.3f", measurement4);


}

void print_adc() {
  Lcd_Out(1,1,measuremen1);
  Lcd_Out(2,1,measuremen2);
  Lcd_Out(1,12,measuremen3);
  Lcd_Out(2,12,measuremen4);
}


void system_init() {
  init_adc();
  Lcd_Init();                        // Initialize LCD
  Lcd_Cmd(_LCD_CLEAR);               // Clear display
  Lcd_Cmd(_LCD_CURSOR_OFF);          // Cursor off
  Lcd_Out(1,3,"ADC  ADS8341");
  Lcd_Out(2,1,"ATmega128 16 MHz");
  Delay_ms(3999);
}


void main() {
  system_init();
  Lcd_Cmd(_LCD_CLEAR);

     while(1){
       // Lcd_Cmd(_LCD_CLEAR);               // Clear display
       adc_read();
       print_adc();
       // Delay_ms(90);
     }


}
